from PyQt5.QtWidgets import QLabel
from PyQt5.QtGui import QPixmap, QIcon
from PyQt5.QtCore import Qt, QTimer, QSize

from users.user_window_default import UserWindowDefaultWidget


if False:
    _("Баланс")
    _("мин")
    _("Месяц")
    _("День")
    _("Задолженность")
    _("Нарушения:")
    _("Опоздания")
    _("Уход раньше")
    _("Отсутствий")
    _("Другие нарушения")
    _("Прогулов")
    _("Несгораемые нарушения")
    _("Отработанное время")
    _("Нормативное время")

SHIFT_Y = 50
PADDING_SHIFT = 60

class BalanceWidget(UserWindowDefaultWidget):
    INFO = [
        {
            'field_name': 'balance',
            'label': "Баланс",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_1.svg',
            'optional': True
        }, {
            'field_name': 'balance_per_month',
            'label': "Месяц",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_m.svg',
            'optional': True
        }, {
            'field_name': 'balance_per_day',
            'label': "День",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_d.svg',
            'optional': True
        }, {
            'field_name': 'indebtedness',
            'label': "Задолженность",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_2.svg',
            'optional': True
        }, {
            'field_name': 'disciplinary_violations',
            'label': "Нарушения:",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_3.svg',
            'optional': True
        }, {
            'field_name': 'disciplinary_violations_per_month',
            'label': "Месяц",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_m.svg',
            'optional': True
        }, {
            'field_name': 'disciplinary_violations_per_day',
            'label': "День",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_d.svg',
            'optional': True
        }, {
            'field_name': 'tardiness',
            'label': "Опоздания",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_4.svg',
            'optional': True
        }, {
            'field_name': 'early_care',
            'label': "Уход раньше",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_5.svg',
            'optional': True
        }, {
            'field_name': 'time_worked',
            'label': "Отработанное время",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_1.svg',
            'optional': True
        }, {
            'field_name': 'time_worked_per_month',
            'label': "Месяц",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_m.svg',
            'optional': True
        }, {
            'field_name': 'time_worked_per_day',
            'label': "День",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_d.svg',
            'optional': True
        }, {
            'field_name': 'standard_time',
            'label': "Нормативное время",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_a.svg',
            'optional': True
        }, {
            'field_name': 'standard_time_per_month',
            'label': "Месяц",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_m.svg',
            'optional': True
        }, {
            'field_name': 'standard_time_per_day',
            'label': "День",
            'sy': SHIFT_Y, 'pad': PADDING_SHIFT, 'info': "мин", 'big': False,
            'pic': 'res/balance_d.svg',
            'optional': True
        }, {
            'field_name': 'absences',
            'label': "Отсутствий",
            'sy': SHIFT_Y, 'pad': 0, 'info': None, 'big': True,
            'pic': 'res/balance_6.svg',
            'optional': True
        }, {
            'field_name': 'other_violations',
            'label': "Другие нарушения",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_7.svg',
            'optional': True
        }, {
            'field_name': 'absenteeism',
            'label': "Прогулов",
            'sy': SHIFT_Y, 'pad': 0, 'info': None, 'big': True,
            'pic': 'res/balance_8.svg',
            'optional': True
        }, {
            'field_name': 'fireproof_violations',
            'label': "Несгораемые нарушения",
            'sy': SHIFT_Y, 'pad': 0, 'info': "мин", 'big': True,
            'pic': 'res/balance_9.svg',
            'optional': True
        }
    ]

    def __init__(self, parent=None):
        super().__init__(parent)

        self.auto_close = QTimer(self)
        self.auto_close.timeout.connect(self.go_back.emit)
        self.auto_close.setInterval(1000 * 10)
        self.auto_close.setSingleShot(True)

        self.list = {}
        for item in BalanceWidget.INFO:
            line = {}

            icon = QLabel(None, self)
            if item['big']:
                icon.resize(60, 60)
                icon.setPixmap(QIcon(item['pic']).pixmap(QSize(60, 60)))
            else:
                icon.resize(50, 50)
                icon.setPixmap(QIcon(item['pic']).pixmap(QSize(50, 50)))
            line['icon'] = icon

            label = QLabel(_(item['label']), self)
            label.resize(600, item['sy'])
            if item['big']:
                label.setObjectName('big')
            else:
                label.setObjectName('small')
            line['label'] = label

            data = QLabel("0", self)
            data.resize(200, item['sy'])
            data.setAlignment(Qt.Alignment(Qt.AlignRight | Qt.AlignVCenter))
            if item['big']:
                data.setObjectName('big')
            else:
                data.setObjectName('small')
            line['data'] = data

            # info = QLabel(_(item['info']), self)
            # info.resize(81, item['sy'])

            # if item['big']:
            #     info.setObjectName('big')
            # else:
            #     info.setObjectName('small')
            # line['info'] = info

            self.list[item['field_name']] = line

        lbl = QLabel("", self)
        lbl.setGeometry(0, 0, 800, 480)
        lbl.setAlignment(Qt.Alignment(Qt.AlignHCenter | Qt.AlignVCenter))
        lbl.setObjectName('big')
        self.error_message = lbl

    def show(self, all_data):

        y = 0

        if 'error' in all_data:
            for _, line in self.list.items():
                for _, element in line.items():
                    element.hide()
            self.error_message.setText(all_data['error'])
            self.error_message.show()
        else:
            self.error_message.hide()
            for item in BalanceWidget.INFO:
                line = self.list[item['field_name']]
                if item['optional'] and item['field_name'] not in all_data:
                    for _, element in line.items():
                        element.hide()
                    continue

                if item['big']:
                    y += 120
                else:
                    y += 60

                if item['big']:
                    line['icon'].move(80, y)
                else:
                    line['icon'].move(170, y)

                line['label'].move(170 + item['pad'], y)

                line['data'].move(520, y)
                if item['field_name'] in all_data:
                    if item['info'] == 'мин':
                        minutes = all_data[item['field_name']]
                        sign = ["", "-"][minutes < 0]
                        line['data'].setText("%s%2d:%02d" %(
                            sign, abs(minutes) // 60, abs(minutes) % 60))
                    else:
                        line['data'].setText(str(all_data[item['field_name']]))
                #
                # line['info'].move(540, y)

                for _, element in line.items():
                    element.show()

        self.auto_close.start()
        super().show()
