# pylint: disable=too-few-public-methods
from PyQt5.QtWidgets import QLabel

from window_default import WindowDefaultWidget


class InfoWidget(WindowDefaultWidget):
    LABEL_STYLES = {
        'left': 'qproperty-alignment: AlignLeft;',
        'right': 'qproperty-alignment: AlignRight;'
                 'background-color: transparent;',
        'center': 'qproperty-alignment: AlignHCenter;'
                  'background-color: transparent;',
    }

    def __init__(self, protocol, parent=None):
        super().__init__(parent)

        self.parent = parent
        self.protocol = protocol

        self.line = 0

        self.labels = [{}, {}, {}, {}, {}, {}, {}, {}]
        for idx, line in enumerate(self.labels):
            for position in ('left', 'right', 'center'):
                label = QLabel('', self)
                label.setGeometry(100, 60 + (5 + 40) * idx, 700-100, 180)
                label.setStyleSheet(InfoWidget.LABEL_STYLES[position])
                label.setWordWrap(True)
                line[position] = label

        protocol.answer.connect(self._on_protocol_answer)

        def _get_data():
            protocol.getSysinfo()
            protocol.getSettings('template')
        protocol.connected.connect(_get_data)
        _get_data()

    def _on_protocol_answer(self, msg):

        def add_line(line, left='', right='', center=''):
            if line > 7:
                return
            self.labels[line]['left'].setText(left)
            self.labels[line]['right'].setText(right)
            self.labels[line]['center'].setText(center)

        if 'answer' in msg:
            answer = msg['answer']
            if 'sysinfo' in answer and answer['sysinfo'] == 'ok':
                line = 0
                items = msg['sysinfo']
                for label, text in sorted(items.items()):
                    add_line(line, label, text)
                    line += 1
            if 'settings' in answer and answer['settings'] == 'ok':
                settings = msg['settings']
                if 'template' in settings:
                    add_line(7, center=settings['template'])
