from PyQt5.QtWidgets import QLabel, QPushButton
from PyQt5.QtGui import QIcon
from PyQt5.QtCore import pyqtSignal, QTimer
from PyQt5 import QtCore

from window_default import WindowDefaultWidget


class ReasonWidget(WindowDefaultWidget):

    accept = pyqtSignal(str)

    def __init__(self, protocol, parent=None):
        super().__init__(parent)


        self.auto_close = QTimer(self)
        self.auto_close.timeout.connect(self.go_back.emit)
        self.auto_close.setInterval(1000 * 20)
        self.auto_close.setSingleShot(True)

        self.protocol = protocol

        protocol.answer.connect(self._on_protocol_answer)
        # protocol.events.connect(self.eventAnswer)

        self._reasons = None

        btn_up = QPushButton(None, self)
        btn_up.setObjectName('up')
        btn_up.setGeometry(686, 85, 754-686, 137-85)
        btn_up.clicked.connect(self._on_btn_up_click)
        self.btn_up = btn_up

        btn_down = QPushButton(None, self)
        btn_down.setObjectName('down')
        btn_down.setGeometry(686, 398, 754-686, 449-398)
        btn_down.clicked.connect(self._on_btn_down_click)
        self.btn_down = btn_down

        self.offset = 0
        self.buttons = {}
        self.update_reasons()
        protocol.getSettings('licon_reason')

    def show(self):
        self.protocol.getSettings('licon_reason')
        self.auto_close.start()
        super().show()

    def update_reasons(self, additional_reasons=None):
        self.offset = 0
        new_reasons = {
            _("Отпуск"): 'res/reason_1.svg',
            _("Выходной день"): 'res/reason_2.svg',
            _("Командировка"): 'res/reason_3.svg',
            _("Больничный"): 'res/reason_4.svg',
            _("Отпуск без сохранения ЗП"): 'res/reason_5.svg',
        }
        if additional_reasons:
            for item in additional_reasons.split(';'):
                if item not in new_reasons:
                    new_reasons[item] = 'res/reason_6.svg'
        self._reasons = new_reasons
        self._update_buttons()

    def _cleanup_obsolete_buttons(self):
        for txt, (button, label) in self.buttons.items():
            if txt not in self._reasons:
                button.deleteLater()
                label.deleteLater()
                self.buttons[txt] = None

    def _update_buttons(self):
        if len(self.buttons) > 20:
            self._cleanup_obsolete_buttons()
        cur_sublist = list(self._reasons)[self.offset:(self.offset+6)]
        for txt, (button, label) in self.buttons.items():
            if txt not in cur_sublist:
                button.hide()
                label.hide()
        print(cur_sublist)
        for idx, txt in enumerate(cur_sublist):
            if txt not in self.buttons:
                self._create_button(txt)
            button, label = self.buttons[txt]
            btn_x = 156 + (idx % 3) * 181
            btn_y = 84 + (idx // 3) * 198
            button.move(btn_x, btn_y)
            label.move(btn_x - 50, btn_y + 90)
            button.show()
            label.show()
        if len(self._reasons) > 6:
            self.btn_up.show()
            self.btn_down.show()
        else:
            self.btn_up.hide()
            self.btn_down.hide()

    def _create_button(self, txt):
        icon = self._reasons[txt]
        button = QPushButton(None, self)
        button.setGeometry(0, 0, 80, 80)
        button.setIcon(QIcon(icon))
        button.setIconSize(QtCore.QSize(77, 77))
        button.clicked.connect(
            lambda: self.accept.emit(self.sender().property('reason')))
        button.clicked.connect(self.go_back.emit)
        button.setProperty('reason', txt)
        button.show()

        label = QLabel(txt, self)
        label.setGeometry(0 - 50, 0 + 90, 90*2, 92)
        label.setWordWrap(True)
        label.show()
        self.buttons[txt] = (button, label)

    def _on_protocol_answer(self, msg):
        if 'answer' in msg:
            answer = msg['answer']

            if 'settings' in answer and answer['settings'] == 'ok':
                settings = msg['settings']
                if 'licon_reason' in settings:
                    self.update_reasons(settings['licon_reason'])

    def _on_btn_up_click(self):
        self.auto_close.start()
        if self.offset >= 3:
            self.offset -= 3
            self._update_buttons()

    def _on_btn_down_click(self):
        self.auto_close.start()
        if self.offset < len(self._reasons) - 6:
            self.offset += 3
            self._update_buttons()
