from PyQt5.QtWidgets import QWidget, QLabel, QPushButton
from PyQt5.QtGui import QIcon
from PyQt5.QtCore import pyqtSignal, QTimer
from PyQt5 import QtCore

class ScreenTestWidget(QWidget):

    def __init__(self, protocol, parent=None):
        super().__init__(parent)
        self.hide()
        W = 800
        H = 480
        self.setGeometry(0, 0, W, H)
        self.setAttribute(QtCore.Qt.WA_StyledBackground)
        X = 10
        Y = 10
        dx = W//X
        dy = H//Y
        for x in range(X):
            for y in range(Y):
                btn = QPushButton(str(x) + ':' + str(y), self)
                btn.setGeometry(x * dx, y * dy, dx, dy)
                btn.setObjectName('screentest')

        self.color_label = QLabel(self)
        self.color_label.setGeometry(0, 0, 800, 480)
        self.is_color_only = True
        self.color_idx = 0
        self.color_timer = QTimer(self)
        self.color_timer.setInterval(1000 * 4)
        self.color_timer.timeout.connect(self._next_color)
        protocol.answer.connect(self._on_protocol_answer)


    def showEvent(self, event):  # pylint: disable-msg=C0103
        """Just extension of QT showEvent method."""
        super().showEvent(event)
        self.raise_()

    def _next_color(self):
        self.color_idx +=1
        if self.color_idx == 1:
            self.color_label.setStyleSheet(
                '* { background-color: rgba(255, 0, 0, 255); }')
            self.color_label.show()
            self.color_timer.start()
        elif self.color_idx == 2:
            self.color_label.setStyleSheet(
                '* { background-color: rgba(0, 255, 0, 255); }')
        elif self.color_idx == 3:
            self.color_label.setStyleSheet(
                '* { background-color: rgba(0, 0, 255, 255); }')
        elif self.color_idx == 4:
            self.color_timer.stop()
            self.color_label.hide()
            self.color_idx = 0
            if self.is_color_only:
                self.hide()

    def _on_protocol_answer(self, msg):
        if 'answer' in msg:
            answer = msg['answer']

            if 'settings' in answer and answer['settings'] == 'ok':
                settings = msg['settings']

                if 'licon_display_test' in settings \
                        and settings['licon_display_test'] == 'yes':
                    self.show()
                    self._next_color()
                if 'licon_ts_test' in settings:
                    if settings['licon_ts_test'] == 'yes':
                        self.show()
                        self.is_color_only = False
                    elif settings['licon_ts_test'] == 'no':
                        self.is_color_only = True
                        if not self.color_timer.isActive():
                            self.hide()
