#!/usr/bin/python3

import sys
import os

import gettext

from PyQt5.QtWidgets import \
    QApplication, QGraphicsScene, QGraphicsView, QLabel
from PyQt5.QtCore import Qt
from PyQt5.QtGui import QFont

from mainwindow import MainWindow
from protocol import Protocol

# os.environ['TSLIB_TSDEVICE'] = '/dev/input/event0'
# os.environ['TSLIB_CALIBFILE'] = '/etc/pointercal'
# os.environ['TSLIB_CONFFILE'] = '/etc/ts.conf'
# os.environ['TSLIB_PLUGINDIR'] = '/usr/lib/ts'
# os.environ['TSLIB_FBDEVICE'] = '/dev/fb0'
# os.environ['TSLIB_CONSOLEDEVICE'] = 'none'
os.environ['QT_QPA_FB_DRM'] = '1'
os.environ['QT_QPA_FB_TSLIB'] = '1'

gettext.bindtextdomain('messages', './locale')
gettext.textdomain('messages')

# Protocol #

protocol = Protocol(1234)

# GUI #

app = QApplication(sys.argv)
app.setFont(QFont('AvenirNextCyr'))

scene = QGraphicsScene(0, 0, 800, 480)

view = QGraphicsView(scene)
view.resize(800, 480)
view.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
view.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
with open('/sys/class/graphics/fbcon/rotate', 'r') as file:
    view.rotate(90*int(file.read()))  # fbcon/rotate contains 0..3 as rotation

with open('main.css', 'r') as fh:
    app.setStyleSheet(fh.read())

view.show()

lbl_loading = QLabel(
    'Ожидаем запуск приложения<br>и установку шаблона...'
    '<br><br>'
    'Waiting for application loading<br>and template selection')
lbl_loading.resize(800, 480)
lbl_loading.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
scene.addWidget(lbl_loading)

def wait_for_language_change(msg):
    global main
    if not ('answer' in msg
            and 'settings' in msg['answer']
            and msg['answer']['settings'] == 'ok'
            and 'licon_lang' in msg['settings']):
        return
    if os.getenv('LANG') != msg['settings']['licon_lang']:
        os.environ['LANG'] = msg['settings']['licon_lang']
        if 'main' in globals() and main:
            sys.exit("Reloading GUI...")
        gettext.translation(
            'messages', localedir='./locale', languages=[os.environ['LANG']],
            fallback=True, codeset='UTF8').install()
        main = MainWindow(protocol)
        scene.addWidget(main)
        protocol.getSettings('licon')


protocol.answer.connect(wait_for_language_change)
protocol.start()

sys.exit(app.exec_())
